import {
  Autocomplete,
  Box,
  TextField,
  Paper,
  Typography,
  Tab,
  Tabs,
} from "@mui/material";
import { Edit, useAutocomplete } from "@refinedev/mui";
import { useForm } from "@refinedev/react-hook-form";
import { Controller } from "react-hook-form";
import { useParams, Link } from "react-router";
import React, { useState, useEffect } from "react";
import { LinkedItems } from "../../components/LinkedItems";
import { CreateSightArticle } from "../../components/CreateSightArticle";
import { ArticleItem, articleFields } from "./types";
import { TOKEN_KEY } from "../../authProvider";
import { observer } from "mobx-react-lite";

import { languageStore } from "../../store/LanguageStore";
import axios from "axios";
import { LanguageSwitch } from "../../components/LanguageSwitch/index";

function a11yProps(index: number) {
  return {
    id: `simple-tab-${index}`,
    "aria-controls": `simple-tabpanel-${index}`,
  };
}

interface TabPanelProps {
  children?: React.ReactNode;
  index: number;
  value: number;
}

function CustomTabPanel(props: TabPanelProps) {
  const { children, value, index, ...other } = props;

  return (
    <div
      role="tabpanel"
      hidden={value !== index}
      id={`simple-tabpanel-${index}`}
      aria-labelledby={`simple-tab-${index}`}
      {...other}
    >
      {value === index && <Box sx={{ p: 3 }}>{children}</Box>}
    </div>
  );
}

export const SightEdit = observer(() => {
  const { id: sightId } = useParams<{ id: string }>();
  const { language, setLanguageAction } = languageStore;

  const [sightData, setSightData] = useState({
    ru: {
      name: "",
      address: "",
    },
    en: {
      name: "",
      address: "",
    },
    zh: {
      name: "",
      address: "",
    },
  });

  const {
    saveButtonProps,
    register,
    control,
    watch,
    getValues,
    setValue,
    formState: { errors },
  } = useForm({
    refineCoreProps: {
      meta: {
        headers: {
          "Accept-Language": language,
        },
      },
    },
  });

  useEffect(() => {
    setLanguageAction("ru");
  }, []);

  const { autocompleteProps: cityAutocompleteProps } = useAutocomplete({
    resource: "city",
    onSearch: (value) => [
      {
        field: "name",
        operator: "contains",
        value,
      },
    ],
    meta: {
      headers: {
        "Accept-Language": "ru",
      },
    },
  });
  const [mediaFile, setMediaFile] = useState<{
    src: string;
    filename: string;
  }>({
    src: "",
    filename: "",
  });

  const [tabValue, setTabValue] = useState(0);
  const { autocompleteProps: mediaAutocompleteProps } = useAutocomplete({
    resource: "media",
    onSearch: (value) => [
      {
        field: "media_name",
        operator: "contains",
        value,
      },
    ],
  });

  const { autocompleteProps: articleAutocompleteProps } = useAutocomplete({
    resource: "article",
    queryOptions: {
      queryKey: ["article", language],
    },
    onSearch: (value) => [
      {
        field: "heading",
        operator: "contains",
        value,
      },
      {
        field: "media_type",
        operator: "contains",
        value,
      },
    ],
  });

  useEffect(() => {
    if (sightData[language as keyof typeof sightData]?.name) {
      setValue("name", sightData[language as keyof typeof sightData]?.name);
    }
    if (sightData[language as keyof typeof sightData]?.address) {
      setValue(
        "address",
        sightData[language as keyof typeof sightData]?.address || ""
      );
    }
  }, [language, sightData, setValue]);

  useEffect(() => {
    const latitude = getValues("latitude");
    const longitude = getValues("longitude");
    if (latitude && longitude) {
      setCoordinatesPreview({
        latitude: latitude,
        longitude: longitude,
      });
    }
  }, [getValues]);

  const handleCoordinatesChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    const [lat, lon] = e.target.value.split(",").map((s) => s.trim());
    setCoordinatesPreview({
      latitude: lat,
      longitude: lon,
    });
    setValue("latitude", lat);
    setValue("longitude", lon);
  };

  // Состояния для предпросмотра
  const [namePreview, setNamePreview] = useState("");
  const [coordinatesPreview, setCoordinatesPreview] = useState({
    latitude: "",
    longitude: "",
  });
  const [selectedArticleIndex, setSelectedArticleIndex] = useState(0);
  const [cityPreview, setCityPreview] = useState("");
  const [thumbnailPreview, setThumbnailPreview] = useState<string | null>(null);
  const [watermarkLUPreview, setWatermarkLUPreview] = useState<string | null>(
    null
  );
  const [watermarkRDPreview, setWatermarkRDPreview] = useState<string | null>(
    null
  );
  const [leftArticlePreview, setLeftArticlePreview] = useState("");
  const [previewArticlePreview, setPreviewArticlePreview] = useState("");
  const [linkedArticles, setLinkedArticles] = useState<ArticleItem[]>([]);
  // Следим за изменениями во всех полях
  const selectedArticle = linkedArticles[selectedArticleIndex];

  const addressContent = watch("address");
  const nameContent = watch("name");
  const latitudeContent = watch("latitude");
  const longitudeContent = watch("longitude");
  const cityContent = watch("city_id");
  const thumbnailContent = watch("thumbnail");
  const watermarkLUContent = watch("watermark_lu");
  const watermarkRDContent = watch("watermark_rd");
  const leftArticleContent = watch("left_article");
  const previewArticleContent = watch("preview_article");

  // Обновляем состояния при изменении полей
  useEffect(() => {
    setNamePreview(nameContent || "");
  }, [nameContent]);

  useEffect(() => {
    return () => {
      setLanguageAction("ru");
    };
  }, []);

  useEffect(() => {
    setCoordinatesPreview({
      latitude: latitudeContent || "",
      longitude: longitudeContent || "",
    });
  }, [latitudeContent, longitudeContent]);

  useEffect(() => {
    const getMedia = async () => {
      if (!linkedArticles[selectedArticleIndex]?.id) return;
      try {
        const response = await axios.get(
          `${import.meta.env.VITE_KRBL_API}/article/${
            linkedArticles[selectedArticleIndex].id
          }/media`,
          {
            headers: {
              Authorization: `Bearer ${localStorage.getItem(TOKEN_KEY)}`,
            },
          }
        );
        const media = response.data[0];
        if (media) {
          setMediaFile({
            src: `${import.meta.env.VITE_KRBL_MEDIA}${
              media.id
            }/download?token=${localStorage.getItem(TOKEN_KEY)}`,
            filename: media.filename,
          });
          console.log(media);
        } else {
          setMediaFile({
            src: "",
            filename: "",
          }); // или другой дефолт
        }
      } catch (error) {
        setMediaFile({
          src: "",
          filename: "",
        }); // или обработка ошибки
      }
    };

    getMedia();
  }, [selectedArticleIndex, linkedArticles]);

  useEffect(() => {
    const selectedCity = cityAutocompleteProps.options.find(
      (option) => option.id === cityContent
    );
    setCityPreview(selectedCity?.name || "");
  }, [cityContent, cityAutocompleteProps.options]);

  useEffect(() => {
    const selectedThumbnail = mediaAutocompleteProps.options.find(
      (option) => option.id === thumbnailContent
    );
    setThumbnailPreview(
      selectedThumbnail
        ? `${import.meta.env.VITE_KRBL_MEDIA}${
            selectedThumbnail.id
          }/download?token=${localStorage.getItem(TOKEN_KEY)}`
        : null
    );
  }, [thumbnailContent, mediaAutocompleteProps.options]);

  useEffect(() => {
    const selectedWatermarkLU = mediaAutocompleteProps.options.find(
      (option) => option.id === watermarkLUContent
    );
    setWatermarkLUPreview(
      selectedWatermarkLU
        ? `${import.meta.env.VITE_KRBL_MEDIA}${
            selectedWatermarkLU.id
          }/download?token=${localStorage.getItem(TOKEN_KEY)}`
        : null
    );
  }, [watermarkLUContent, mediaAutocompleteProps.options]);

  useEffect(() => {
    const selectedWatermarkRD = mediaAutocompleteProps.options.find(
      (option) => option.id === watermarkRDContent
    );
    setWatermarkRDPreview(
      selectedWatermarkRD
        ? `${import.meta.env.VITE_KRBL_MEDIA}${
            selectedWatermarkRD.id
          }/download?token=${localStorage.getItem(TOKEN_KEY)}`
        : null
    );
  }, [watermarkRDContent, mediaAutocompleteProps.options]);

  useEffect(() => {
    const selectedLeftArticle = articleAutocompleteProps.options.find(
      (option) => option.id === leftArticleContent
    );
    setLeftArticlePreview(selectedLeftArticle?.heading || "");
  }, [leftArticleContent, articleAutocompleteProps.options]);

  useEffect(() => {
    const selectedPreviewArticle = articleAutocompleteProps.options.find(
      (option) => option.id === previewArticleContent
    );
    setPreviewArticlePreview(selectedPreviewArticle?.heading || "");
  }, [previewArticleContent, articleAutocompleteProps.options]);

  const handleLanguageChange = (lang: string) => {
    setSightData((prevData) => ({
      ...prevData,
      [language]: {
        name: watch("name") ?? "",
        address: watch("address") ?? "",
      },
    }));
    setLanguageAction(lang);
  };
  useEffect(() => {
    return () => {
      setLanguageAction("ru");
    };
  }, [setLanguageAction]);

  return (
    <Box sx={{ display: "flex", flexDirection: "column", gap: 2 }}>
      <Box sx={{ borderBottom: 1, borderColor: "divider" }}>
        <Tabs
          value={tabValue}
          onChange={(_, newValue) => setTabValue(newValue)}
          aria-label="basic tabs example"
        >
          <Tab label="Левый виджет" {...a11yProps(1)} />
          <Tab label="Правый виджет" {...a11yProps(2)} />
          <Tab label="Основная информация" {...a11yProps(3)} />
        </Tabs>
      </Box>

      <CustomTabPanel value={tabValue} index={0}>
        <Edit
          saveButtonProps={saveButtonProps}
          footerButtonProps={{
            sx: {
              bottom: 0,
              left: 0,
            },
          }}
        >
          <Box
            sx={{
              maxWidth: "50%",
              display: "flex",
              flexDirection: "column",
              gap: 2,
              position: "relative",
            }}
          >
            <Box
              component="form"
              sx={{ flex: 1, display: "flex", flexDirection: "column" }}
              autoComplete="off"
            >
              <TextField
                {...register("name", {
                  required: "Это поле является обязательным",
                })}
                error={!!(errors as any)?.name}
                helperText={(errors as any)?.name?.message}
                margin="normal"
                fullWidth
                InputLabelProps={{ shrink: true }}
                type="text"
                label={"Название *"}
                name="name"
              />
            </Box>
            <LanguageSwitch />
            <Box sx={{ mt: 3 }}>
              <LinkedItems<ArticleItem>
                type="edit"
                parentId={sightId!}
                dragAllowed={true}
                setItemsParent={setLinkedArticles}
                parentResource="sight"
                fields={articleFields}
                childResource="article"
                title="статьи"
              />

              <CreateSightArticle
                parentId={sightId!}
                parentResource="sight"
                childResource="article"
                title="статью"
              />
            </Box>
          </Box>
        </Edit>
        <Paper
          sx={{
            position: "fixed",
            p: 2,

            width: "30%",

            top: "178px",

            right: 50,
            zIndex: 1000,
            borderRadius: 2,
            border: "1px solid",
            borderColor: "primary.main",
            bgcolor: (theme) =>
              theme.palette.mode === "dark" ? "background.paper" : "#fff",
          }}
        >
          <Typography variant="h6" gutterBottom color="primary">
            Предпросмотр
          </Typography>

          <Box sx={{ mb: 2 }}>
            {mediaFile.src && (
              <>
                {mediaFile.filename.endsWith(".mp4") ? (
                  <video
                    style={{ width: "100%", height: "100%" }}
                    src={mediaFile.src}
                    controls
                  />
                ) : (
                  <img
                    style={{ width: "100%", height: "100%" }}
                    src={mediaFile.src}
                    alt="Предпросмотр"
                  />
                )}
              </>
            )}
            <p style={{ fontSize: "12px", color: "white" }}>
              {mediaFile.filename}
            </p>
          </Box>
          {/* Водяные знаки */}
          <Box sx={{ mb: 2 }}>
            <Box sx={{ display: "flex", flexDirection: "column", gap: 2 }}>
              {selectedArticle && (
                <Typography
                  variant="h4"
                  gutterBottom
                  sx={{ color: "text.primary" }}
                >
                  {selectedArticle.heading}
                </Typography>
              )}

              {selectedArticle && (
                <Typography
                  variant="body1"
                  gutterBottom
                  sx={{ color: "text.primary" }}
                >
                  {selectedArticle.body}
                </Typography>
              )}
            </Box>
            {/* Координаты */}
            <Box sx={{ display: "flex", gap: 1, mt: 2 }}>
              {linkedArticles.map((article, index) => (
                <Box
                  key={article.id}
                  onClick={() => setSelectedArticleIndex(index)}
                  sx={{
                    cursor: "pointer",
                    bgcolor:
                      selectedArticleIndex === index
                        ? "primary.main"
                        : "transparent",
                    color: selectedArticleIndex === index ? "white" : "inherit",
                    p: 1,
                    borderRadius: 1,
                  }}
                >
                  <Typography variant="body1" gutterBottom>
                    {article.heading}
                  </Typography>
                </Box>
              ))}
            </Box>
          </Box>
        </Paper>
      </CustomTabPanel>

      <CustomTabPanel value={tabValue} index={1}>
        <Edit
          saveButtonProps={saveButtonProps}
          footerButtonProps={{
            sx: {
              bottom: 0,
              left: 0,
            },
          }}
        >
          <Box sx={{ display: "flex", gap: 2, position: "relative" }}>
            <Box
              sx={{
                display: "flex",
                flexDirection: "column",
                flex: 1,
                maxWidth: "50%",
                gap: 10,
                justifyContent: "space-between",
              }}
            >
              {/* Language Selection */}

              <Box
                sx={{
                  display: "flex",
                  gap: 2,
                }}
              >
                <Box
                  sx={{
                    cursor: "pointer",
                    flex: 1,
                    display: "flex",
                    justifyContent: "center",
                    bgcolor: language === "ru" ? "primary.main" : "transparent",
                    color: language === "ru" ? "white" : "inherit",
                    p: 1,
                    borderRadius: 1,
                  }}
                  onClick={() => handleLanguageChange("ru")}
                >
                  RU
                </Box>
                <Box
                  sx={{
                    cursor: "pointer",
                    flex: 1,
                    display: "flex",
                    justifyContent: "center",
                    bgcolor: language === "en" ? "primary.main" : "transparent",
                    color: language === "en" ? "white" : "inherit",
                    p: 1,
                    borderRadius: 1,
                  }}
                  onClick={() => handleLanguageChange("en")}
                >
                  EN
                </Box>
                <Box
                  sx={{
                    cursor: "pointer",
                    flex: 1,
                    display: "flex",
                    justifyContent: "center",
                    bgcolor: language === "zh" ? "primary.main" : "transparent",
                    color: language === "zh" ? "white" : "inherit",
                    p: 1,
                    borderRadius: 1,
                  }}
                  onClick={() => handleLanguageChange("zh")}
                >
                  ZH
                </Box>
              </Box>

              {/* Форма редактирования */}
              <Box
                component="form"
                sx={{ flex: 1, display: "flex", flexDirection: "column" }}
                autoComplete="off"
              >
                <TextField
                  {...register("name", {
                    required: "Это поле является обязательным",
                  })}
                  error={!!(errors as any)?.name}
                  helperText={(errors as any)?.name?.message}
                  margin="normal"
                  fullWidth
                  InputLabelProps={{ shrink: true }}
                  type="text"
                  label={"Название *"}
                  name="name"
                />

                <input
                  type="hidden"
                  {...register("longitude", {
                    value: coordinatesPreview.longitude,
                    required: "Это поле является обязательным",
                    valueAsNumber: true,
                  })}
                />
                <input
                  type="hidden"
                  {...register("latitude", {
                    value: coordinatesPreview.latitude,
                    required: "Это поле является обязательным",
                    valueAsNumber: true,
                  })}
                />

                {/* 
          <TextField
            {...register("longitude", {
              required: "Это поле является обязательным",
              valueAsNumber: true,
            })}
            error={!!(errors as any)?.longitude}
            helperText={(errors as any)?.longitude?.message}
            margin="normal"
            fullWidth
            InputLabelProps={{ shrink: true }}
            type="number"
            label={"Долгота *"}
            name="longitude"
          /> */}

                {/* <TextField
            {...register("coordinates", {
              required: "Это поле является обязательным",
              valueAsNumber: true,
            })}
            error={!!(errors as any)?.coordinates}
            helperText={(errors as any)?.coordinates?.message}
            margin="normal"
            fullWidth
            InputLabelProps={{ shrink: true }}
            type="number"
            label={"Координаты *"}
            name="coordinates"
          /> */}

                <TextField
                  {...register("address", {
                    required: "Это поле является обязательным",
                  })}
                  error={!!(errors as any)?.address}
                  helperText={(errors as any)?.address?.message}
                  margin="normal"
                  fullWidth
                  InputLabelProps={{ shrink: true }}
                  type="text"
                  label={"Адрес *"}
                  name="address"
                />

                <Controller
                  control={control}
                  name="city_id"
                  rules={{ required: "Это поле является обязательным" }}
                  defaultValue={null}
                  render={({ field }) => (
                    <Autocomplete
                      {...cityAutocompleteProps}
                      value={
                        cityAutocompleteProps.options.find(
                          (option) => option.id === field.value
                        ) || null
                      }
                      onChange={(_, value) => {
                        field.onChange(value?.id || "");
                      }}
                      getOptionLabel={(item) => {
                        return item ? item.name : "";
                      }}
                      isOptionEqualToValue={(option, value) => {
                        return option.id === value?.id;
                      }}
                      filterOptions={(options, { inputValue }) => {
                        return options.filter((option) =>
                          option.name
                            .toLowerCase()
                            .includes(inputValue.toLowerCase())
                        );
                      }}
                      renderInput={(params) => (
                        <TextField
                          {...params}
                          label="Выберите город"
                          margin="normal"
                          variant="outlined"
                          error={!!errors.city_id}
                          helperText={(errors as any)?.city_id?.message}
                          required
                        />
                      )}
                    />
                  )}
                />

                <Controller
                  control={control}
                  name="thumbnail"
                  defaultValue={null}
                  render={({ field }) => (
                    <Autocomplete
                      {...mediaAutocompleteProps}
                      value={
                        mediaAutocompleteProps.options.find(
                          (option) => option.id === field.value
                        ) || null
                      }
                      onChange={(_, value) => {
                        field.onChange(value?.id || "");
                      }}
                      getOptionLabel={(item) => {
                        return item ? item.media_name : "";
                      }}
                      isOptionEqualToValue={(option, value) => {
                        return option.id === value?.id;
                      }}
                      filterOptions={(options, { inputValue }) => {
                        return options.filter(
                          (option) =>
                            option.media_name
                              .toLowerCase()
                              .includes(inputValue.toLowerCase()) &&
                            option.media_type === 3
                        );
                      }}
                      renderInput={(params) => (
                        <TextField
                          {...params}
                          label="Выберите логотип достопримечательности"
                          margin="normal"
                          variant="outlined"
                          error={!!errors.arms}
                          helperText={(errors as any)?.arms?.message}
                          required
                        />
                      )}
                    />
                  )}
                />

                <Box sx={{ display: "none" }}>
                  <Controller
                    control={control}
                    name="watermark_lu"
                    defaultValue={null}
                    render={({ field }) => (
                      <Autocomplete
                        {...mediaAutocompleteProps}
                        value={
                          mediaAutocompleteProps.options.find(
                            (option) => option.id === field.value
                          ) || null
                        }
                        onChange={(_, value) => {
                          field.onChange(value?.id || "");
                        }}
                        getOptionLabel={(item) => {
                          return item ? item.media_name : "";
                        }}
                        isOptionEqualToValue={(option, value) => {
                          return option.id === value?.id;
                        }}
                        filterOptions={(options, { inputValue }) => {
                          return options.filter((option) =>
                            option.media_name
                              .toLowerCase()
                              .includes(inputValue.toLowerCase())
                          );
                        }}
                        renderInput={(params) => (
                          <TextField
                            {...params}
                            label="Выберите водный знак (Левый верх)"
                            margin="normal"
                            variant="outlined"
                            error={!!errors.arms}
                            helperText={(errors as any)?.arms?.message}
                            required
                          />
                        )}
                      />
                    )}
                  />
                </Box>
                <Box sx={{ display: "none" }}>
                  <Controller
                    control={control}
                    name="watermark_rd"
                    defaultValue={null}
                    render={({ field }) => (
                      <Autocomplete
                        {...mediaAutocompleteProps}
                        value={
                          mediaAutocompleteProps.options.find(
                            (option) => option.id === field.value
                          ) || null
                        }
                        onChange={(_, value) => {
                          field.onChange(value?.id || "");
                        }}
                        getOptionLabel={(item) => {
                          return item ? item.media_name : "";
                        }}
                        isOptionEqualToValue={(option, value) => {
                          return option.id === value?.id;
                        }}
                        filterOptions={(options, { inputValue }) => {
                          return options.filter((option) =>
                            option.media_name
                              .toLowerCase()
                              .includes(inputValue.toLowerCase())
                          );
                        }}
                        renderInput={(params) => (
                          <TextField
                            {...params}
                            label="Выберите водный знак (Правый вверх)"
                            margin="normal"
                            variant="outlined"
                            error={!!errors.arms}
                            helperText={(errors as any)?.arms?.message}
                            required
                          />
                        )}
                      />
                    )}
                  />
                </Box>

                <Controller
                  control={control}
                  name="left_article"
                  defaultValue={null}
                  render={({ field }) => (
                    <Autocomplete
                      {...articleAutocompleteProps}
                      value={
                        articleAutocompleteProps.options.find(
                          (option) => option.id === field.value
                        ) || null
                      }
                      onChange={(_, value) => {
                        field.onChange(value?.id || "");
                      }}
                      getOptionLabel={(item) => {
                        return item ? item.heading : "";
                      }}
                      isOptionEqualToValue={(option, value) => {
                        return option.id === value?.id;
                      }}
                      filterOptions={(options, { inputValue }) => {
                        return options.filter((option) =>
                          option.heading
                            .toLowerCase()
                            .includes(inputValue.toLowerCase())
                        );
                      }}
                      renderInput={(params) => (
                        <TextField
                          {...params}
                          label="Левая статья"
                          margin="normal"
                          variant="outlined"
                          error={!!errors.arms}
                          helperText={(errors as any)?.arms?.message}
                          required
                        />
                      )}
                    />
                  )}
                />

                <Controller
                  control={control}
                  name="preview_article"
                  defaultValue={null}
                  render={({ field }) => (
                    <Autocomplete
                      {...articleAutocompleteProps}
                      value={
                        articleAutocompleteProps.options.find(
                          (option) => option.id === field.value
                        ) || null
                      }
                      onChange={(_, value) => {
                        field.onChange(value?.id || "");
                      }}
                      getOptionLabel={(item) => {
                        return item ? item.heading : "";
                      }}
                      isOptionEqualToValue={(option, value) => {
                        return option.id === value?.id;
                      }}
                      filterOptions={(options, { inputValue }) => {
                        return options.filter((option) =>
                          option.heading
                            .toLowerCase()
                            .includes(inputValue.toLowerCase())
                        );
                      }}
                      renderInput={(params) => (
                        <TextField
                          {...params}
                          label="Медиа-предпросмотр"
                          margin="normal"
                          variant="outlined"
                          error={!!errors.arms}
                          helperText={(errors as any)?.arms?.message}
                          required
                        />
                      )}
                    />
                  )}
                />
              </Box>
            </Box>

            {/* Блок предпросмотра */}
            <Paper
              sx={{
                position: "fixed",
                p: 2,
                width: "30%",

                top: "179px",

                right: 50,
                zIndex: 1000,
                borderRadius: 2,
                border: "1px solid",
                borderColor: "primary.main",
                bgcolor: (theme) =>
                  theme.palette.mode === "dark" ? "background.paper" : "#fff",
              }}
            >
              <Typography variant="h6" gutterBottom color="primary">
                Предпросмотр
              </Typography>

              {/* Название достопримечательности */}
              <Typography
                variant="h4"
                sx={{
                  wordWrap: "break-word",
                  color: (theme) =>
                    theme.palette.mode === "dark" ? "grey.300" : "grey.800",
                  mb: 3,
                }}
              >
                {namePreview}
              </Typography>

              {/* Город */}
              <Typography variant="body1" sx={{ mb: 2 }}>
                <Box component="span" sx={{ color: "text.secondary" }}>
                  Город:{" "}
                </Box>
                <Box
                  component="span"
                  sx={{
                    color: (theme) =>
                      theme.palette.mode === "dark" ? "grey.300" : "grey.800",
                  }}
                >
                  {cityPreview}
                </Box>
              </Typography>

              {/* Адрес */}
              <Typography variant="body1" sx={{ mb: 2 }}>
                <Box component="span" sx={{ color: "text.secondary" }}>
                  Адрес:{" "}
                </Box>
                <Box
                  component="span"
                  sx={{
                    color: (theme) =>
                      theme.palette.mode === "dark" ? "grey.300" : "grey.800",
                  }}
                >
                  {addressContent}
                </Box>
              </Typography>

              {/* Обложка */}
              {thumbnailPreview && (
                <Box sx={{ mb: 2 }}>
                  <Typography
                    variant="body1"
                    gutterBottom
                    sx={{ color: "text.secondary" }}
                  >
                    Логотип достопримечательности:
                  </Typography>
                  <Box
                    component="img"
                    src={thumbnailPreview}
                    alt="Логотип"
                    sx={{
                      maxWidth: "100%",
                      height: "40vh",
                      borderRadius: 2,
                      border: "1px solid",
                      borderColor: "primary.main",
                    }}
                  />
                </Box>
              )}
            </Paper>
          </Box>
        </Edit>
      </CustomTabPanel>
      <CustomTabPanel value={tabValue} index={2}>
        <Edit
          saveButtonProps={saveButtonProps}
          footerButtonProps={{
            sx: {
              bottom: 0,
              left: 0,
            },
          }}
        >
          <Box
            sx={{
              maxWidth: "50%",
              display: "flex",
              gap: 2,
              position: "relative",
            }}
          >
            <Box
              component="form"
              sx={{ flex: 1, display: "flex", flexDirection: "column" }}
              autoComplete="off"
            >
              <LanguageSwitch />
              <Controller
                control={control}
                name="watermark_lu"
                defaultValue={null}
                render={({ field }) => (
                  <Autocomplete
                    {...mediaAutocompleteProps}
                    value={
                      mediaAutocompleteProps.options.find(
                        (option) => option.id === field.value
                      ) || null
                    }
                    onChange={(_, value) => {
                      field.onChange(value?.id || "");
                    }}
                    getOptionLabel={(item) => {
                      return item ? item.media_name : "";
                    }}
                    isOptionEqualToValue={(option, value) => {
                      return option.id === value?.id;
                    }}
                    filterOptions={(options, { inputValue }) => {
                      return options.filter((option) =>
                        option.media_name
                          .toLowerCase()
                          .includes(inputValue.toLowerCase())
                      );
                    }}
                    renderInput={(params) => (
                      <TextField
                        {...params}
                        label="Выберите водный знак (Левый верх)"
                        margin="normal"
                        variant="outlined"
                        error={!!errors.arms}
                        helperText={(errors as any)?.arms?.message}
                        required
                      />
                    )}
                  />
                )}
              />

              <Controller
                control={control}
                name="watermark_rd"
                defaultValue={null}
                render={({ field }) => (
                  <Autocomplete
                    {...mediaAutocompleteProps}
                    value={
                      mediaAutocompleteProps.options.find(
                        (option) => option.id === field.value
                      ) || null
                    }
                    onChange={(_, value) => {
                      field.onChange(value?.id || "");
                    }}
                    getOptionLabel={(item) => {
                      return item ? item.media_name : "";
                    }}
                    isOptionEqualToValue={(option, value) => {
                      return option.id === value?.id;
                    }}
                    filterOptions={(options, { inputValue }) => {
                      return options.filter((option) =>
                        option.media_name
                          .toLowerCase()
                          .includes(inputValue.toLowerCase())
                      );
                    }}
                    renderInput={(params) => (
                      <TextField
                        {...params}
                        label="Выберите водный знак (Правый вверх)"
                        margin="normal"
                        variant="outlined"
                        error={!!errors.arms}
                        helperText={(errors as any)?.arms?.message}
                        required
                      />
                    )}
                  />
                )}
              />

              <TextField
                value={`${coordinatesPreview.latitude}, ${coordinatesPreview.longitude}`}
                onChange={handleCoordinatesChange}
                error={!!(errors as any)?.latitude}
                helperText={(errors as any)?.latitude?.message}
                margin="normal"
                fullWidth
                InputLabelProps={{ shrink: true }}
                type="text"
                label={"Координаты *"}
              />
            </Box>

            <Paper
              sx={{
                position: "fixed",
                p: 2,

                width: "30%",

                top: "178px",

                right: 50,
                zIndex: 1000,
                borderRadius: 2,
                border: "1px solid",
                borderColor: "primary.main",
                bgcolor: (theme) =>
                  theme.palette.mode === "dark" ? "background.paper" : "#fff",
              }}
            >
              <Typography variant="h6" gutterBottom color="primary">
                Предпросмотр
              </Typography>

              {/* Водяные знаки */}
              <Box sx={{ mb: 2 }}>
                <Typography
                  variant="body1"
                  gutterBottom
                  sx={{ color: "text.secondary" }}
                >
                  Водяные знаки:
                </Typography>
                <Box sx={{ display: "flex", gap: 2 }}>
                  {watermarkLUPreview && (
                    <Box>
                      <Typography
                        variant="body2"
                        gutterBottom
                        sx={{ color: "text.secondary" }}
                      >
                        Левый верхний:
                      </Typography>
                      <Box
                        component="img"
                        src={watermarkLUPreview}
                        alt="Водяной знак (ЛВ)"
                        sx={{
                          width: 100,
                          height: 100,
                          objectFit: "cover",
                          borderRadius: 1,
                          border: "1px solid",
                          borderColor: "primary.main",
                        }}
                      />
                    </Box>
                  )}
                  {watermarkRDPreview && (
                    <Box>
                      <Typography
                        variant="body2"
                        gutterBottom
                        sx={{ color: "text.secondary" }}
                      >
                        Правый верхний:
                      </Typography>
                      <Box
                        component="img"
                        src={watermarkRDPreview}
                        alt="Водяной знак (ПН)"
                        sx={{
                          width: 100,
                          height: 100,
                          objectFit: "cover",
                          borderRadius: 1,
                          border: "1px solid",
                          borderColor: "primary.main",
                        }}
                      />
                    </Box>
                  )}
                </Box>
                {/* Координаты */}
                <Typography
                  variant="body1"
                  sx={{ display: "flex", flexDirection: "column", mb: 2 }}
                >
                  <Box component="span" sx={{ color: "text.secondary" }}>
                    Координаты:{" "}
                  </Box>
                  <Box
                    component="span"
                    sx={{
                      color: (theme) =>
                        theme.palette.mode === "dark" ? "grey.300" : "grey.800",
                    }}
                  >
                    {`${coordinatesPreview.latitude}, ${coordinatesPreview.longitude}`}
                  </Box>
                </Typography>
              </Box>
            </Paper>
          </Box>
        </Edit>
      </CustomTabPanel>
    </Box>
  );
});
